==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebTreeItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeItemDescription } from "./WebTreeItemDescription";
/**
 * @hidden
 */
export let WebTreeItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeItemDescriptionMetadata.a == null) {
                WebTreeItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeItemDescriptionMetadata.c(WebTreeItemDescriptionMetadata.a);
            }
            if (a.k(WebTreeItemDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebTreeItemDescriptionMetadata.a);
            WebTreeItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeItem");
            a.item("__tagNameWC", "String:igc-tree-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Parent", "ExportedType:WebTreeItem");
            a.item("Level", "Number:double");
            a.item("Label", "String");
            a.item("Expanded", "Boolean");
            a.item("Active", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("Selected", "Boolean");
            a.item("Loading", "Boolean");
            a.item("Value", "Unknown");
        }
        static d(a) {
            WebTreeItemDescriptionMetadata.b(a);
            a.ad("WebTreeItem", () => new WebTreeItemDescription());
            a.ac("WebTreeItem", WebTreeItemDescriptionMetadata.a);
        }
    }
    WebTreeItemDescriptionMetadata.$t = markType(WebTreeItemDescriptionMetadata, 'WebTreeItemDescriptionMetadata');
    WebTreeItemDescriptionMetadata.a = null;
    return WebTreeItemDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebTreeItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeItemDescription } from "./WebTreeItemDescription";
/**
 * @hidden
 */
export let WebTreeItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeItemDescriptionMetadata.a == null) {
                WebTreeItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeItemDescriptionMetadata.c(WebTreeItemDescriptionMetadata.a);
            }
            if (a.k(WebTreeItemDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebTreeItemDescriptionMetadata.a);
            WebTreeItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeItem");
            a.item("__tagNameWC", "String:igc-tree-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Parent", "ExportedType:WebTreeItem");
            a.item("Level", "Number:double");
            a.item("Label", "String");
            a.item("Expanded", "Boolean");
            a.item("Active", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("Selected", "Boolean");
            a.item("Loading", "Boolean");
            a.item("Value", "Unknown");
        }
        static d(a) {
            WebTreeItemDescriptionMetadata.b(a);
            a.ae("WebTreeItem", () => new WebTreeItemDescription());
            a.ad("WebTreeItem", WebTreeItemDescriptionMetadata.a);
        }
    }
    WebTreeItemDescriptionMetadata.$t = markType(WebTreeItemDescriptionMetadata, 'WebTreeItemDescriptionMetadata');
    WebTreeItemDescriptionMetadata.a = null;
    return WebTreeItemDescriptionMetadata;
})();
